from enum import Enum


class GetCompletedJobResponse200RawFlowFailureModuleSleepType0Type(str, Enum):
    STATIC = "static"

    def __str__(self) -> str:
        return str(self.value)
